@@ -155,16 +155,18 @@ gmag_compositor_paint_window (GmagWinPtr pgmag_win, XserverRegion region)
 	if (region) {
 		XFixesIntersectRegion (dpy, final_clip, region,
 				       pgmag_win->clip);
+		printf ("we should clip at %d, %d\n", -(pgmag_win->attr.x), -(pgmag_win->attr.y));
 		XFixesSetPictureClipRegion (dpy, pgmag_win->pic,
-					    -(pgmag_win->attr.x),
-					    -(pgmag_win->attr.y), final_clip);
+					    0,
+					    0, final_clip);
 
 		rectlist = XFixesFetchRegion (dpy, final_clip, &howmany);
 	} else {
+		printf ("we should clip at %d, %d\n", -(pgmag_win->attr.x), -(pgmag_win->attr.y));
 		XFixesSetPictureClipRegion (dpy,
 					    pgmag_win->pic,
-					    -(pgmag_win->attr.x),
-					    -(pgmag_win->attr.y),
+					    0,
+					    0,
 					    pgmag_win->clip);
 		rectlist = XFixesFetchRegion (dpy, pgmag_win->clip, &howmany);
 	}
@@ -174,6 +176,8 @@ gmag_compositor_paint_window (GmagWinPtr pgmag_win, XserverRegion region)
 			  0, 0, 0, 0, pgmag_win->attr.x, pgmag_win->attr.y,
 			  pgmag_win->attr.width, pgmag_win->attr.height);
 
+	XSync (dpy, FALSE);
+
 	if (rectlist != NULL) {/* reply from fetch */
 		for (i=0; i < howmany; ++i) {
 			gmag_gs_notify_damage (mag_ref, &rectlist[i]);
@@ -801,6 +805,17 @@ gmag_compositor_init (Magnifier *magnifier, Display *dpy_conn)
 		mag_ref = magnifier;
 		root_window = GDK_WINDOW_XWINDOW (mag_ref->priv->root);
 
+		if (exp_region != None) {
+			XFixesDestroyRegion (dpy, tmp_region);
+			XFixesDestroyRegion (dpy, new_region);
+			XFixesDestroyRegion (dpy, old_region);
+			XFixesDestroyRegion (dpy, exp_region);
+			tmp_region = None;
+			new_region = None;
+			old_region = None;
+			exp_region = None;
+		}
+
 #ifndef HAVE_OVERLAY
 		g_warning ("update composite to version 0.3 or higher to " \
 			   "have overlay window support.\n");
