@@ -20,7 +20,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
+#define GDK_PIXBUF_ENABLE_BACKEND
 #include "config.h"
 #include "magnifier.h"
 #include "magnifier-private.h"
@@ -48,7 +48,6 @@
 #include <stdlib.h>
 
 #include <glib.h>
-
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
@@ -161,11 +160,11 @@ gmag_gs_check_set_struts (Magnifier *magnifier)
 #if GTK_CHECK_VERSION (2,19,5)
 	if (magnifier &&
 	    magnifier->priv && magnifier->priv->w && gtk_widget_get_realized (magnifier->priv->w) &&
-	    magnifier->priv->w->window) 
+	    gtk_widget_get_window (magnifier->priv->w))
 #else
 	if (magnifier &&
 	    magnifier->priv && magnifier->priv->w && GTK_WIDGET_REALIZED (magnifier->priv->w) &&
-	    magnifier->priv->w->window) 
+	    gtk_widget_get_window (magnifier->priv->w))
 #endif
 	{
 		Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
@@ -223,13 +222,13 @@ gmag_gs_check_set_struts (Magnifier *magnifier)
 		}
 		
 		gdk_error_trap_push ();
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
-				 GDK_WINDOW_XWINDOW (widget->window), 
+		XChangeProperty (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (widget)),
+				 GDK_WINDOW_XWINDOW (gtk_widget_get_window (widget)),
 				 atom_strut,
 				 XA_CARDINAL, 32, PropModeReplace,
 				 (guchar *) &struts, 4);
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
-				 GDK_WINDOW_XWINDOW (widget->window), 
+		XChangeProperty (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (widget)),
+				 GDK_WINDOW_XWINDOW (gtk_widget_get_window (widget)),
 				 atom_strut_partial,
 				 XA_CARDINAL, 32, PropModeReplace,
 				 (guchar *) &struts, 12); 
@@ -261,30 +260,30 @@ gmag_gs_reset_overlay_at_idle (gpointer data)
 		if (magnifier->priv && magnifier->priv->w &&
 		    GTK_WIDGET_REALIZED (magnifier->priv->w))
 #endif
-			if (magnifier->priv->w->window) {
+			if (gtk_widget_get_window (magnifier->priv->w)) {
 #ifdef HAVE_OVERLAY
 				gint      x, y, over_w, over_h;
 				if (!magnifier->priv->overlay) {
-					magnifier->priv->overlay = gdk_window_foreign_new (XCompositeGetOverlayWindow (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->root)));
+					magnifier->priv->overlay = gdk_window_foreign_new (XCompositeGetOverlayWindow (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (magnifier->priv->w)), GDK_WINDOW_XID (magnifier->priv->root)));
 					gdk_window_get_position (
-						magnifier->priv->w->window, &x,
+						gtk_widget_get_window (magnifier->priv->w), &x,
 						&y);
 					gdk_drawable_get_size (
-						magnifier->priv->w->window,
+						gtk_widget_get_window (magnifier->priv->w),
 						&over_w, &over_h);
 					gdk_window_move_resize (
 						magnifier->priv->overlay, x, y,
 						over_w, over_h);
 					gdk_window_reparent (
-						magnifier->priv->w->window,
+						gtk_widget_get_window (magnifier->priv->w),
 						magnifier->priv->overlay, 0, 0);
 				}
 #ifdef HAVE_SHAPEINPUT			
-				XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->overlay), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
+				XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (magnifier->priv->w)), GDK_WINDOW_XID (magnifier->priv->overlay), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
 #endif /* HAVE_SHAPEINPUT */
 #else
 #ifdef HAVE_SHAPEINPUT
-				XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (magnifier->priv->w->window), GDK_WINDOW_XID (magnifier->priv->w->window), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
+				XShapeCombineRectangles (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (magnifier->priv->w)), GDK_WINDOW_XID (gtk_widget_get_window (magnifier->priv->w)), ShapeInput, 0, 0, NULL, 0, ShapeSet, YXBanded);
 #endif /* HAVE_SHAPEINPUT */
 #endif /* HAVE_OVERLAY */
 				return FALSE;
@@ -324,7 +323,7 @@ gmag_gs_magnifier_realize (GtkWidget *widget)
 	Atom wm_window_protocols[2];
 	Atom wm_type_atoms[1];
 	Atom net_wm_window_type;
-	GdkDisplay *target_display = gdk_drawable_get_display (widget->window);
+	GdkDisplay *target_display = gdk_drawable_get_display (gtk_widget_get_window (widget));
 	
 	static gboolean initialized = FALSE;
 
@@ -342,18 +341,18 @@ gmag_gs_magnifier_realize (GtkWidget *widget)
 	wm_hints.flags = InputHint;
 	wm_hints.input = False;
 	
-	XSetWMHints (GDK_WINDOW_XDISPLAY (widget->window),
-		     GDK_WINDOW_XWINDOW (widget->window), &wm_hints);
+	XSetWMHints (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (widget)),
+		     GDK_WINDOW_XWINDOW (gtk_widget_get_window (widget)), &wm_hints);
 	
-	XSetWMProtocols (GDK_WINDOW_XDISPLAY (widget->window),
-			 GDK_WINDOW_XWINDOW (widget->window), wm_window_protocols, 2);
+	XSetWMProtocols (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (widget)),
+			 GDK_WINDOW_XWINDOW (gtk_widget_get_window (widget)), wm_window_protocols, 2);
 
 	net_wm_window_type = gdk_x11_get_xatom_by_name_for_display 
 		(target_display, "_NET_WM_WINDOW_TYPE");
 
 	if (net_wm_window_type && wm_type_atoms[0])
-		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window),
-				 GDK_WINDOW_XWINDOW (widget->window),
+		XChangeProperty (GDK_WINDOW_XDISPLAY (gtk_widget_get_window (widget)),
+				 GDK_WINDOW_XWINDOW (gtk_widget_get_window (widget)),
 				 net_wm_window_type,
 				 XA_ATOM, 32, PropModeReplace,
 				 (guchar *)wm_type_atoms,
@@ -385,8 +384,8 @@ gmag_gs_events_handler (GIOChannel *source, GIOCondition condition,
 	if (magnifier->priv->overlay)
 		mag_window = GDK_WINDOW_XID (magnifier->priv->overlay);
 #else
-	if (magnifier->priv->w && magnifier->priv->w->window)
-		mag_window = GDK_WINDOW_XID (magnifier->priv->w->window);
+	if (magnifier->priv->w && gtk_widget_get_window (magnifier->priv->w))
+		mag_window = GDK_WINDOW_XID (gtk_widget_get_window (magnifier->priv->w));
 #endif /* HAVE_OVERLAY */
 
 	do
@@ -450,7 +449,7 @@ gmag_gs_events_handler (GIOChannel *source, GIOCondition condition,
 static gboolean
 gmag_gs_use_damage ()
 {
-	gint major, event, error;
+	gint major, error;
 	if (XQueryExtension (
 		    dpy, "DAMAGE", &major, &damage_event_base, &error) &&
 	    !g_getenv ("MAGNIFIER_IGNORE_DAMAGE")) {
